@@ -36,7 +36,6 @@ def sqlconnect(str):
     user,pawd,host,database = re.findall(
         "(.*):(.*)@([0-9]{0,3}.[0-9]{0,3}.[0-9]{0,3}.[0-9]{0,3}):(.*)"
     , str )[0]
-
     cnt = mysql.connector.connect(
         host=host,
         database=database,
@@ -58,7 +57,9 @@ def loader(nd):
     file.close()
 
     data = {}
-    if ext == '.yaml' and text.strip() != '':
+    if text.strip() == '':
+        return data
+    elif ext == '.yaml':
         data = yaml.safe_load( text )
     elif ext == '.json':
         data = json.loads(text )
@@ -100,7 +101,7 @@ class jict( defaultdict ):
 
                 if len(nd) >= 5 and nd[-5:] in [ '.yaml' , '.json' ]:
 
-                    if (nd[:6] == 'shm//:' or nd[:6] == 'set://') and nd[-5:] == '.json':
+                    if ( nd[:6] == 'shm//:' or nd[:6] == 'set://' ) and nd[-5:] == '.json':
                         nd = nd[6:]
                         dt = to_jict( loader(nd) )
                         dt.storepath = nd
@@ -191,6 +192,9 @@ class jict( defaultdict ):
         return self
 
     def increase(self,key,val,create = False ):
+        print('increase : function is deprecated us "set_max" instead')
+        return self.set_max(key,val,create)
+    def set_max(self,key,val,create = False):
         if key not in self.keys():
             if not create: return self[key]
             else:
@@ -204,6 +208,9 @@ class jict( defaultdict ):
         return self[key]
 
     def decrease(self,key,val,create = False ):
+        print('decrease : function is deprecated us "set_min" instead')
+        return self.set_min(key,val,create)
+    def set_min(self,key,val,create = False ):
         if key not in self.keys():
             if not create: return self[key]
             else:
